.. _capi-topology:

Function manipulating ``CHFL_TOPOLOGY``
---------------------------------------

.. doxygentypedef:: CHFL_TOPOLOGY

.. doxygenfunction:: chfl_topology

.. doxygenfunction:: chfl_topology_from_frame

.. doxygenfunction:: chfl_topology_copy

.. doxygenfunction:: chfl_topology_atoms_count

.. doxygenfunction:: chfl_topology_resize

.. doxygenfunction:: chfl_topology_add_atom

.. doxygenfunction:: chfl_topology_remove

.. doxygenfunction:: chfl_topology_add_bond

.. doxygenfunction:: chfl_topology_remove_bond

.. doxygenfunction:: chfl_topology_bonds_count

.. doxygenfunction:: chfl_topology_angles_count

.. doxygenfunction:: chfl_topology_dihedrals_count

.. doxygenfunction:: chfl_topology_impropers_count

.. doxygenfunction:: chfl_topology_bonds

.. doxygenfunction:: chfl_topology_angles

.. doxygenfunction:: chfl_topology_dihedrals

.. doxygenfunction:: chfl_topology_impropers

.. doxygenfunction:: chfl_topology_add_residue

.. doxygenfunction:: chfl_topology_residues_count

.. doxygenfunction:: chfl_topology_residues_linked

.. doxygenfunction:: chfl_topology_free
